==> anet-java-sdk-1.8.2-sources.jar: net/authorize/data/xml/reporting/ReportingDetails.java <==
package net.authorize.data.xml.reporting;

import java.util.ArrayList;
import java.util.Date;

/**
 * Reporting details.
 */
public class ReportingDetails {

    public static String DATE_FORMAT = "yyyy-MM-dd'T'HH:mm:ss";
    public static String DATE_FORMAT_FULL = "yyyy-MM-dd'T'HH:mm:ss.SSS";

	private boolean batchIncludeStatistics = false;
	private Date batchFirstSettlementDate = null;
	private Date batchLastSettlementDate = null;
	private String batchId = null;
	private String transactionId = null;
	private ArrayList<BatchDetails> batchDetailsList = new ArrayList<BatchDetails>();
	private ArrayList<TransactionDetails> transactionDetailList = new ArrayList<TransactionDetails>();

	private ReportingDetails () { }

	public static ReportingDetails createReportingDetails() {
		return new ReportingDetails();
	}

	/**
	 * @return the batchIncludeStatistics
	 */
	public boolean isBatchIncludeStatistics() {
		return batchIncludeStatistics;
	}

	/**
	 * @param batchIncludeStatistics the batchIncludeStatistics to set
	 */
	public void setBatchIncludeStatistics(boolean batchIncludeStatistics) {
		this.batchIncludeStatistics = batchIncludeStatistics;
	}

	/**
	 * @return the batchFirstSettlementDate
	 */
	public Date getBatchFirstSettlementDate() {
		return batchFirstSettlementDate;
	}

	/**
	 * @param batchFirstSettlementDate the batchFirstSettlementDate to set
	 */
	public void setBatchFirstSettlementDate(Date batchFirstSettlementDate) {
		this.batchFirstSettlementDate = batchFirstSettlementDate;
	}

	/**
	 * @param batchFirstSettlementDate the batchFirstSettlementDate to set
	 */
	public void setBatchFirstSettlementDate(String batchFirstSettlementDate) {
		this.batchFirstSettlementDate = net.authorize.util.DateUtil.getDateFromFormattedDate(
				batchFirstSettlementDate, DATE_FORMAT);
	}

	/**
	 * @return the batchLastSettlementDate
	 */
	public Date getBatchLastSettlementDate() {
		return batchLastSettlementDate;
	}

	/**
	 * @param batchLastSettlementDate the batchLastSettlementDate to set
	 */
	public void setBatchLastSettlementDate(Date batchLastSettlementDate) {
		this.batchLastSettlementDate = batchLastSettlementDate;
	}

	/**
	 * @param batchLastSettlementDate the batchLastSettlementDate to set
	 */
	public void setBatchLastSettlementDate(String batchLastSettlementDate) {
		this.batchLastSettlementDate = net.authorize.util.DateUtil.getDateFromFormattedDate(
				batchLastSettlementDate, DATE_FORMAT);
	}

	/**
	 * @return the batchId
	 */
	public String getBatchId() {
		return batchId;
	}

	/**
	 * @param batchId the batchId to set
	 */
	public void setBatchId(String batchId) {
		this.batchId = batchId;
	}

	/**
	 * @return the transactionId
	 */
	public String getTransactionId() {
		return transactionId;
	}

	/**
	 * @param transactionId the transactionId to set
	 */
	public void setTransactionId(String transactionId) {
		this.transactionId = transactionId;
	}

	/**
	 * @return the batchDetailList
	 */
	public ArrayList<BatchDetails> getBatchDetailsList() {
		return batchDetailsList;
	}

	/**
	 * @param batchDetailList the batchDetailList to set
	 */
	public void setBatchDetailsList(ArrayList<BatchDetails> batchDetailList) {
		this.batchDetailsList = batchDetailList;
	}

	/**
	 * @return the transactionDetailList
	 */
	public ArrayList<TransactionDetails> getTransactionDetailList() {
		return transactionDetailList;
	}

	/**
	 * @param transactionDetailList the transactionDetailList to set
	 */
	public void setTransactionDetailList(
			ArrayList<TransactionDetails> transactionDetailList) {
		this.transactionDetailList = transactionDetailList;
	}


}

==> anet-java-sdk-1.9.9-sources.jar: net/authorize/data/xml/reporting/ReportingDetails.java <==
package net.authorize.data.xml.reporting;

import java.util.ArrayList;
import java.util.Date;

/**
 * Reporting details.
 * 
 * @deprecated since version 1.9.8
 * @deprecated We have reorganized and simplified the Authorize.Net API to ease integration and to focus on merchants' needs.
 * @deprecated We have deprecated AIM, ARB, CIM, and Reporting as separate options, in favor of AuthorizeNet::API (package: net.authorize.api.*).
 * @deprecated We have also deprecated SIM as a separate option, in favor of Accept Hosted. See https://developer.authorize.net/api/reference/features/accept_hosted.html for details on Accept Hosted.
 * @deprecated For details on AIM, see https://github.com/AuthorizeNet/sample-code-java/tree/master/src/main/java/net/authorize/sample/PaymentTransactions.
 * @deprecated For details on the deprecation and replacement of legacy Authorize.Net methods, visit https://developer.authorize.net/api/upgrade_guide/.
 *
 */
@Deprecated
public class ReportingDetails {

    public static String DATE_FORMAT = "yyyy-MM-dd'T'HH:mm:ss";
    public static String DATE_FORMAT_FULL = "yyyy-MM-dd'T'HH:mm:ss.SSS";

	private boolean batchIncludeStatistics = false;
	private Date batchFirstSettlementDate = null;
	private Date batchLastSettlementDate = null;
	private String batchId = null;
	private String transactionId = null;
	private ArrayList<BatchDetails> batchDetailsList = new ArrayList<BatchDetails>();
	private ArrayList<TransactionDetails> transactionDetailList = new ArrayList<TransactionDetails>();

	private ReportingDetails () { }

	public static ReportingDetails createReportingDetails() {
		return new ReportingDetails();
	}

	/**
	 * @return the batchIncludeStatistics
	 */
	public boolean isBatchIncludeStatistics() {
		return batchIncludeStatistics;
	}

	/**
	 * @param batchIncludeStatistics the batchIncludeStatistics to set
	 */
	public void setBatchIncludeStatistics(boolean batchIncludeStatistics) {
		this.batchIncludeStatistics = batchIncludeStatistics;
	}

	/**
	 * @return the batchFirstSettlementDate
	 */
	public Date getBatchFirstSettlementDate() {
		return batchFirstSettlementDate;
	}

	/**
	 * @param batchFirstSettlementDate the batchFirstSettlementDate to set
	 */
	public void setBatchFirstSettlementDate(Date batchFirstSettlementDate) {
		this.batchFirstSettlementDate = batchFirstSettlementDate;
	}

	/**
	 * @param batchFirstSettlementDate the batchFirstSettlementDate to set
	 */
	public void setBatchFirstSettlementDate(String batchFirstSettlementDate) {
		this.batchFirstSettlementDate = net.authorize.util.DateUtil.getDateFromFormattedDate(
				batchFirstSettlementDate, DATE_FORMAT);
	}

	/**
	 * @return the batchLastSettlementDate
	 */
	public Date getBatchLastSettlementDate() {
		return batchLastSettlementDate;
	}

	/**
	 * @param batchLastSettlementDate the batchLastSettlementDate to set
	 */
	public void setBatchLastSettlementDate(Date batchLastSettlementDate) {
		this.batchLastSettlementDate = batchLastSettlementDate;
	}

	/**
	 * @param batchLastSettlementDate the batchLastSettlementDate to set
	 */
	public void setBatchLastSettlementDate(String batchLastSettlementDate) {
		this.batchLastSettlementDate = net.authorize.util.DateUtil.getDateFromFormattedDate(
				batchLastSettlementDate, DATE_FORMAT);
	}

	/**
	 * @return the batchId
	 */
	public String getBatchId() {
		return batchId;
	}

	/**
	 * @param batchId the batchId to set
	 */
	public void setBatchId(String batchId) {
		this.batchId = batchId;
	}

	/**
	 * @return the transactionId
	 */
	public String getTransactionId() {
		return transactionId;
	}

	/**
	 * @param transactionId the transactionId to set
	 */
	public void setTransactionId(String transactionId) {
		this.transactionId = transactionId;
	}

	/**
	 * @return the batchDetailList
	 */
	public ArrayList<BatchDetails> getBatchDetailsList() {
		return batchDetailsList;
	}

	/**
	 * @param batchDetailList the batchDetailList to set
	 */
	public void setBatchDetailsList(ArrayList<BatchDetails> batchDetailList) {
		this.batchDetailsList = batchDetailList;
	}

	/**
	 * @return the transactionDetailList
	 */
	public ArrayList<TransactionDetails> getTransactionDetailList() {
		return transactionDetailList;
	}

	/**
	 * @param transactionDetailList the transactionDetailList to set
	 */
	public void setTransactionDetailList(
			ArrayList<TransactionDetails> transactionDetailList) {
		this.transactionDetailList = transactionDetailList;
	}


}
